==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/who-info.cc <==
// Who-info object.
//
// $Id: who-info.cc,v 1.6 1994/07/16 17:48:06 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <stdlib.h>
#include "who-info.h"
#include "prot-a-LyStr.h"


Who_info::Who_info()
: person(0), what_am_i_doing(),user_name(), 
    working_conference(0), session_no(0)
{
}


Who_info::Who_info(const Who_info &w)
: person(w.person), what_am_i_doing(w.what_am_i_doing),
    user_name(w.user_name), working_conference(w.working_conference),
    session_no(w.session_no)
{
}


Who_info::Who_info(prot_a_LyStr &prot_a_string)
{
    parse(prot_a_string);
}


Who_info::~Who_info()
{
}



Who_info &
Who_info::operator =(const Who_info &w)
{
    person = w.person;
    what_am_i_doing = w.what_am_i_doing;
    user_name = w.user_name;
    working_conference = w.working_conference;
    session_no = w.session_no;

    return *this;
}


void
Who_info::parse(prot_a_LyStr &prot_a_string)
{
    person = prot_a_string.stol();
    working_conference = prot_a_string.stol();
    session_no = prot_a_string.stol();
    what_am_i_doing = prot_a_string.stos();
    user_name = prot_a_string.stos();
}


Pers_no
Who_info::pers_no() const
{
    return person;
}


Conf_no
Who_info::working_conf() const
{
    return working_conference;
}


Session_no
Who_info::session() const
{
    return session_no;
}


LyStr
Who_info::doing() const
{
    return what_am_i_doing;
}


LyStr
Who_info::username() const
{
    return user_name;
}

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/who-info.cc <==
// Who-info object.
//
// $Id: who-info.cc,v 1.8 1995/11/14 06:06:47 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <stdlib.h>
#include "who-info.h"
#include "prot-a-LyStr.h"


Who_info::Who_info()
    : person(0),
      working_conference(0),
      session_no(0),
      what_am_i_doing(),
      user_name()
{
}


Who_info::Who_info(const Who_info &w)
    : person(w.person),
      working_conference(w.working_conference),  
      session_no(w.session_no),
      what_am_i_doing(w.what_am_i_doing),
      user_name(w.user_name)
{
}


Who_info::Who_info(prot_a_LyStr &prot_a_string)
{
    parse(prot_a_string);
}


Who_info::~Who_info()
{
}



Who_info &
Who_info::operator =(const Who_info &w)
{
    person = w.person;
    what_am_i_doing = w.what_am_i_doing;
    user_name = w.user_name;
    working_conference = w.working_conference;
    session_no = w.session_no;

    return *this;
}


void
Who_info::parse(prot_a_LyStr &prot_a_string)
{
    person = prot_a_string.stol();
    working_conference = prot_a_string.stol();
    session_no = prot_a_string.stol();
    what_am_i_doing = prot_a_string.stos();
    user_name = prot_a_string.stos();
}


Pers_no
Who_info::pers_no() const
{
    return person;
}


Conf_no
Who_info::working_conf() const
{
    return working_conference;
}


Session_no
Who_info::session() const
{
    return session_no;
}


LyStr
Who_info::doing() const
{
    return what_am_i_doing;
}


LyStr
Who_info::username() const
{
    return user_name;
}
